featureflags.ftypes package
===========================

Submodules
----------

featureflags.ftypes.boolean module
----------------------------------

.. automodule:: featureflags.ftypes.boolean
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.ftypes.integer module
----------------------------------

.. automodule:: featureflags.ftypes.integer
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.ftypes.interface module
------------------------------------

.. automodule:: featureflags.ftypes.interface
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.ftypes.json module
-------------------------------

.. automodule:: featureflags.ftypes.json
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.ftypes.number module
---------------------------------

.. automodule:: featureflags.ftypes.number
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.ftypes.string module
---------------------------------

.. automodule:: featureflags.ftypes.string
   :members:
   :undoc-members:
   :show-inheritance:

featureflags.ftypes.utils module
--------------------------------

.. automodule:: featureflags.ftypes.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: featureflags.ftypes
   :members:
   :undoc-members:
   :show-inheritance:
